@@ -7,7 +7,7 @@ import pandas as pd
 
 import requests
 
-BASE_URL = 'https://api.algosquare.ai/api'
+BASE_URL = 'https://api.algosquare.ai'
 
 class ApiObject(ABC):
     def __init__(self, entry):
