@@ -228,7 +228,7 @@ for scorer_name in SCORERS:
 
             METRICS[_map_scorer_name(scorer_name)] = (metric, params)
 
-def get_metric(metric_name: str, **kwargs) -> Metric:
+def get_metric(metric_name: str, **kwargs: Union[str, int]) -> Metric:
     """
     Returns metric from string.
 
