@@ -1,16 +1,20 @@
 """Test algo functionality."""
 import inspect
+
+from types import ModuleType
+from typing import Any, Union
+
 from .errors import TestError
 from .tabular import test_tabular_algo
-from ..base.algo import Algo
-from ..base.tabular import TabularClassificationAutoML, TabularRegressionAutoML
+from ..base.algo import Algo, extract_algo_statics
+from ..base.tabular import TabularClassificationAlgo, TabularRegressionAlgo
 
-def test_algo(algo, output_dir, timeout = 300, nan_fraction = 0.1):
+def test_algo(algo_class: type[Algo], output_dir: str, timeout: int = 300, nan_fraction: float = 0.1) -> None:
     """
     Function for testing algo functionality.
 
     Args:
-        algo: Algo class.
+        algo_class: subclass of Algo.
         output_dir: local directory for saving model.
         timeout: search time in seconds.
         nan_fraction: probability of null values in data.
@@ -18,12 +22,14 @@ def test_algo(algo, output_dir, timeout = 300, nan_fraction = 0.1):
     Returns:
         None.
     """
-    if issubclass(algo, TabularClassificationAutoML) or issubclass(algo, TabularRegressionAutoML):
-        return test_tabular_algo(algo, output_dir, timeout, nan_fraction)
+    extract_algo_statics(algo_class)
+
+    if issubclass(algo_class, TabularClassificationAlgo) or issubclass(algo_class, TabularRegressionAlgo):
+        test_tabular_algo(algo_class, output_dir, timeout, nan_fraction)
     else:
         raise TestError('invalid algo class')
 
-def test_package(package, output_dir, **kwargs):
+def test_package(package: ModuleType, output_dir: str, **kwargs: Union[int, float]) -> None:
     """
     Function for testing algos in package.
 
